@@ -17,8 +17,9 @@ class VenueDetails : public QWidget
 public:
     explicit VenueDetails(QWidget *parent = 0);
     ~VenueDetails();
+public slots:
     void setVenue(f_venue v);
-
+    void getVenueDetails(QString id);
 private:
     Ui::VenueDetails *ui;
     f_venue venue;
@@ -27,6 +28,7 @@ private:
     ImageCache * ic;
     CheckinDetails * cd;
 
+
 private slots:
     void on_pbCheckin_clicked();
 };
